@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: config.h 9117 2008-11-02 14:30:05Z xleroy $ */
+/* $Id: config.h 9153 2008-12-03 18:09:09Z doligez $ */
 
 #ifndef CAML_CONFIG_H
 #define CAML_CONFIG_H
@@ -25,8 +25,8 @@
 #define ARCH_UINT64_TYPE unsigned long long
 #define ARCH_INT64_PRINTF_FORMAT "ll"
 #define ARCH_BIG_ENDIAN
-#define ARCH_ALIGN_DOUBLE
-#define ARCH_ALIGN_INT64
+#undef ARCH_ALIGN_DOUBLE
+#undef ARCH_ALIGN_INT64
 #undef NONSTANDARD_DIV_MOD
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/local/lib/ocaml"
@@ -57,6 +57,8 @@
 #define HAS_WAITPID
 #define HAS_WAIT4
 #define HAS_GETGROUPS
+#define HAS_SETGROUPS
+#define HAS_INITGROUPS
 #define HAS_TERMIOS
 #define HAS_ASYNC_IO
 #define HAS_SETITIMER
@@ -70,6 +72,7 @@
 #define SUPPORT_DYNAMIC_LINKING
 #define HAS_MMAP
 #define HAS_SIGWAIT
+#define HAS_LIBBFD
 
 #ifndef CAML_NAME_SPACE
 #include "compatibility.h"
