@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: unix.mli,v 1.69 2002/07/23 13:40:02 xleroy Exp $ *)
+(* $Id: unix.mli 10450 2010-05-21 12:00:49Z doligez $ *)
 
 (** Interface to the Unix system *)
 
@@ -90,7 +90,7 @@ type error =
   | EOVERFLOW           (** File size or position not representable *)
 
   | EUNKNOWNERR of int  (** Unknown error *)
-(** The type of error codes. 
+(** The type of error codes.
    Errors defined in the POSIX standard
    and additional errors from UNIX98 and BSD.
    All other errors are mapped to EUNKNOWNERR.
@@ -118,7 +118,7 @@ val handle_unix_error : ('a -> 'b) -> 'a -> 'b
 val environment : unit -> string array
 (** Return the process environment, as an array of strings
     with the format ``variable=value''. *)
-        
+
 val getenv : string -> string
 (** Return the value associated to a variable in the process
    environment. Raise [Not_found] if the variable is unbound.
@@ -135,8 +135,8 @@ val putenv : string -> string -> unit
 
 
 type process_status =
-    WEXITED of int 
-        (** The process terminated normally by [exit]; 
+    WEXITED of int
+        (** The process terminated normally by [exit];
            the argument is the return code. *)
   | WSIGNALED of int
         (** The process was killed by a signal;
@@ -144,7 +144,9 @@ type process_status =
   | WSTOPPED of int
         (** The process was stopped by a signal; the argument is the
            signal number. *)
-(** The termination status of a process. *)
+(** The termination status of a process.  See module {!Sys} for the
+    definitions of the standard signal numbers.  Note that they are
+    not the numbers used by the OS. *)
 
 
 type wait_flag =
@@ -153,20 +155,23 @@ type wait_flag =
   | WUNTRACED (** report also the children that receive stop signals. *)
 (** Flags for {!Unix.waitpid}. *)
 
-val execv : string -> string array -> unit
+val execv : string -> string array -> 'a
 (** [execv prog args] execute the program in file [prog], with
-   the arguments [args], and the current process environment. *)
+   the arguments [args], and the current process environment.
+   These [execv*] functions never return: on success, the current
+   program is replaced by the new one;
+   on failure, a {!Unix.Unix_error} exception is raised. *)
 
-val execve : string -> string array -> string array -> unit
+val execve : string -> string array -> string array -> 'a
 (** Same as {!Unix.execv}, except that the third argument provides the
    environment to the program executed. *)
 
-val execvp : string -> string array -> unit
-(** Same as {!Unix.execv} respectively, except that
+val execvp : string -> string array -> 'a
+(** Same as {!Unix.execv}, except that
    the program is searched in the path. *)
 
-val execvpe : string -> string array -> string array -> unit
-(** Same as {!Unix.execvp} respectively, except that
+val execvpe : string -> string array -> string array -> 'a
+(** Same as {!Unix.execve}, except that
    the program is searched in the path. *)
 
 val fork : unit -> int
@@ -178,7 +183,7 @@ val wait : unit -> int * process_status
    and termination status. *)
 
 val waitpid : wait_flag list -> int -> int * process_status
-(** Same as {!Unix.wait}, but waits for the process whose pid is given.
+(** Same as {!Unix.wait}, but waits for the child process whose pid is given.
    A pid of [-1] means wait for any child.
    A pid of [0] means wait for any child in the same process group
    as the current process.
@@ -218,7 +223,7 @@ val stdout : file_descr
 (** File descriptor for standard output.*)
 
 val stderr : file_descr
-(** File descriptor for standard standard error. *)
+(** File descriptor for standard error. *)
 
 type open_flag =
     O_RDONLY                    (** Open for reading *)
@@ -237,7 +242,8 @@ type open_flag =
 
 
 type file_perm = int
-(** The type of file access rights. *)
+(** The type of file access rights, e.g. [0o640] is read and write for user,
+    read for group, none for others *)
 
 val openfile : string -> open_flag list -> file_perm -> file_descr
 (** Open the named file with the given flags. Third argument is
@@ -256,9 +262,13 @@ val write : file_descr -> string -> int -> int -> int
 (** [write fd buff ofs len] writes [len] characters to descriptor
    [fd], taking them from string [buff], starting at position [ofs]
    in string [buff]. Return the number of characters actually
-   written. *)
-
+   written.  [write] repeats the writing operation until all characters
+   have been written or an error occurs.  *)
 
+val single_write : file_descr -> string -> int -> int -> int
+(** Same as [write], but attempts to write only once.
+   Thus, if an error occurs, [single_write] guarantees that no data
+   has been written. *)
 
 (** {6 Interfacing with the standard input/output library} *)
 
@@ -302,7 +312,7 @@ val ftruncate : file_descr -> int -> unit
    to the given size. *)
 
 
-(** {6 File statistics} *)
+(** {6 File status} *)
 
 
 type file_kind =
@@ -326,21 +336,24 @@ type stats =
     st_size : int;              (** Size in bytes *)
     st_atime : float;           (** Last access time *)
     st_mtime : float;           (** Last modification time *)
-    st_ctime : float;           (** Last status change time *) 
+    st_ctime : float;           (** Last status change time *)
   }
-(** The informations returned by the {!Unix.stat} calls. *)
+(** The information returned by the {!Unix.stat} calls. *)
 
 val stat : string -> stats
-(** Return the informations for the named file. *)
+(** Return the information for the named file. *)
 
 val lstat : string -> stats
 (** Same as {!Unix.stat}, but in case the file is a symbolic link,
-   return the informations for the link itself. *)
+   return the information for the link itself. *)
 
 val fstat : file_descr -> stats
-(** Return the informations for the file associated with the given
+(** Return the information for the file associated with the given
    descriptor. *)
 
+val isatty : file_descr -> bool
+(** Return [true] if the given file descriptor refers to a terminal or
+   console window, [false] otherwise. *)
 
 (** {6 File operations on large files} *)
 
@@ -361,7 +374,7 @@ module LargeFile :
         st_size : int64;            (** Size in bytes *)
         st_atime : float;           (** Last access time *)
         st_mtime : float;           (** Last modification time *)
-        st_ctime : float;           (** Last status change time *) 
+        st_ctime : float;           (** Last status change time *)
       }
     val stat : string -> stats
     val lstat : string -> stats
@@ -416,7 +429,8 @@ val fchown : file_descr -> int -> int -> unit
 (** Change the owner uid and owner gid of an opened file. *)
 
 val umask : int -> int
-(** Set the process creation mask, and return the previous mask. *)
+(** Set the process's file mode creation mask, and return the previous
+    mask. *)
 
 val access : string -> access_permission list -> unit
 (** Check that the process has the given permissions over the named
@@ -560,23 +574,23 @@ val open_process_full :
    and standard error of the command. *)
 
 val close_process_in : in_channel -> process_status
-(** Close channels opened by {!Unix.open_process_in}, 
+(** Close channels opened by {!Unix.open_process_in},
    wait for the associated command to terminate,
    and return its termination status. *)
 
 val close_process_out : out_channel -> process_status
-(** Close channels opened by {!Unix.open_process_out}, 
+(** Close channels opened by {!Unix.open_process_out},
    wait for the associated command to terminate,
    and return its termination status. *)
 
 val close_process : in_channel * out_channel -> process_status
-(** Close channels opened by {!Unix.open_process}, 
+(** Close channels opened by {!Unix.open_process},
    wait for the associated command to terminate,
    and return its termination status. *)
 
 val close_process_full :
   in_channel * out_channel * in_channel -> process_status
-(** Close channels opened by {!Unix.open_process_full}, 
+(** Close channels opened by {!Unix.open_process_full},
    wait for the associated command to terminate,
    and return its termination status. *)
 
@@ -627,23 +641,37 @@ val lockf : file_descr -> lock_command -> int -> unit
    [fd] (as set by {!Unix.lseek}), and extends [size] bytes forward if
    [size] is positive, [size] bytes backwards if [size] is negative,
    or to the end of the file if [size] is zero.
-   A write lock (set with [F_LOCK] or [F_TLOCK]) prevents any other
+   A write lock prevents any other
    process from acquiring a read or write lock on the region.
-   A read lock (set with [F_RLOCK] or [F_TRLOCK]) prevents any other
+   A read lock prevents any other
    process from acquiring a write lock on the region, but lets
-   other processes acquire read locks on it. *)
+   other processes acquire read locks on it.
+
+   The [F_LOCK] and [F_TLOCK] commands attempts to put a write lock
+   on the specified region.
+   The [F_RLOCK] and [F_TRLOCK] commands attempts to put a read lock
+   on the specified region.
+   If one or several locks put by another process prevent the current process
+   from acquiring the lock, [F_LOCK] and [F_RLOCK] block until these locks
+   are removed, while [F_TLOCK] and [F_TRLOCK] fail immediately with an
+   exception.
+   The [F_ULOCK] removes whatever locks the current process has on
+   the specified region.
+   Finally, the [F_TEST] command tests whether a write lock can be
+   acquired on the specified region, without actually putting a lock.
+   It returns immediately if successful, or fails otherwise. *)
 
 
 (** {6 Signals}
    Note: installation of signal handlers is performed via
-   the functions {!Sys.signal} and {!Sys.set_signal}. 
+   the functions {!Sys.signal} and {!Sys.set_signal}.
 *)
 
 val kill : int -> int -> unit
 (** [kill pid sig] sends signal number [sig] to the process
    with id [pid]. *)
 
-type sigprocmask_command = 
+type sigprocmask_command =
     SIG_SETMASK
   | SIG_BLOCK
   | SIG_UNBLOCK
@@ -662,7 +690,7 @@ val sigpending : unit -> int list
 (** Return the set of blocked signals that are currently pending. *)
 
 val sigsuspend : int list -> unit
-(** [sigsuspend sigs] atomically sets the blocked signals to [sig]
+(** [sigsuspend sigs] atomically sets the blocked signals to [sigs]
    and waits for a non-ignored, non-blocked signal to be delivered.
    On return, the blocked signals are reset to their initial value. *)
 
@@ -677,12 +705,12 @@ type process_times =
   { tms_utime : float;  (** User time for the process *)
     tms_stime : float;  (** System time for the process *)
     tms_cutime : float; (** User time for the children processes *)
-    tms_cstime : float; (** System time for the children processes *) 
+    tms_cstime : float; (** System time for the children processes *)
   }
 (** The execution times (CPU times) of a process. *)
 
 type tm =
-  { tm_sec : int;               (** Seconds 0..59 *)
+  { tm_sec : int;               (** Seconds 0..60 *)
     tm_min : int;               (** Minutes 0..59 *)
     tm_hour : int;              (** Hours 0..23 *)
     tm_mday : int;              (** Day of month 1..31 *)
@@ -690,7 +718,7 @@ type tm =
     tm_year : int;              (** Year - 1900 *)
     tm_wday : int;              (** Day of week (Sunday is 0) *)
     tm_yday : int;              (** Day of year 0..365 *)
-    tm_isdst : bool;            (** Daylight time savings in effect *) 
+    tm_isdst : bool;            (** Daylight time savings in effect *)
   }
 (** The type representing wallclock time and calendar date. *)
 
@@ -704,7 +732,7 @@ val gettimeofday : unit -> float
 
 val gmtime : float -> tm
 (** Convert a time in seconds, as returned by {!Unix.time}, into a date and
-   a time. Assumes Greenwich meridian time zone, also known as UTC. *)
+   a time. Assumes UTC (Coordinated Universal Time), also known as GMT. *)
 
 val localtime : float -> tm
 (** Convert a time in seconds, as returned by {!Unix.time}, into a date and
@@ -712,10 +740,13 @@ val localtime : float -> tm
 
 val mktime : tm -> float * tm
 (** Convert a date and time, specified by the [tm] argument, into
-   a time in seconds, as returned by {!Unix.time}. Also return a normalized
-   copy of the given [tm] record, with the [tm_wday], [tm_yday],
-   and [tm_isdst] fields recomputed from the other fields.
-   The [tm] argument is interpreted in the local time zone. *)
+   a time in seconds, as returned by {!Unix.time}.  The [tm_isdst],
+   [tm_wday] and [tm_yday] fields of [tm] are ignored.  Also return a
+   normalized copy of the given [tm] record, with the [tm_wday],
+   [tm_yday], and [tm_isdst] fields recomputed from the other fields,
+   and the other fields normalized (so that, e.g., 40 October is
+   changed into 9 November).  The [tm] argument is interpreted in the
+   local time zone. *)
 
 val alarm : int -> int
 (** Schedule a [SIGALRM] signal after the given number of seconds. *)
@@ -729,10 +760,11 @@ val times : unit -> process_times
 val utimes : string -> float -> float -> unit
 (** Set the last access time (second arg) and last modification time
    (third arg) for a file. Times are expressed in seconds from
-   00:00:00 GMT, Jan. 1, 1970. *)
+   00:00:00 GMT, Jan. 1, 1970.  A time of [0.0] is interpreted as the
+   current time. *)
 
 type interval_timer =
-    ITIMER_REAL 
+    ITIMER_REAL
       (** decrements in real time, and sends the signal [SIGALRM] when expired.*)
   | ITIMER_VIRTUAL
       (**  decrements in process virtual time, and sends [SIGVTALRM] when expired. *)
@@ -744,7 +776,7 @@ type interval_timer =
 
 type interval_timer_status =
   { it_interval : float;         (** Period *)
-    it_value : float;            (** Current value of the timer *) 
+    it_value : float;            (** Current value of the timer *)
   }
 (** The type describing the status of an interval timer *)
 
@@ -788,6 +820,16 @@ val getgroups : unit -> int array
 (** Return the list of groups to which the user executing the process
    belongs. *)
 
+val setgroups : int array -> unit
+  (** [setgroups groups] sets the supplementary group IDs for the
+      calling process. Appropriate privileges are required. *)
+
+val initgroups : string -> int -> unit
+  (** [initgroups user group] initializes the group access list by
+      reading the group database /etc/group and using all groups of
+      which [user] is a member. The additional group [group] is also
+      added to the list. *)
+
 type passwd_entry =
   { pw_name : string;
     pw_passwd : string;
@@ -795,7 +837,7 @@ type passwd_entry =
     pw_gid : int;
     pw_gecos : string;
     pw_dir : string;
-    pw_shell : string 
+    pw_shell : string
   }
 (** Structure of entries in the [passwd] database. *)
 
@@ -803,7 +845,7 @@ type group_entry =
   { gr_name : string;
     gr_passwd : string;
     gr_gid : int;
-    gr_mem : string array 
+    gr_mem : string array
   }
 (** Structure of entries in the [groups] database. *)
 
@@ -834,25 +876,42 @@ type inet_addr
 (** The abstract type of Internet addresses. *)
 
 val inet_addr_of_string : string -> inet_addr
-(** Conversions between string with the format [XXX.YYY.ZZZ.TTT]
-   and Internet addresses. [inet_addr_of_string] raises [Failure]
-   when given a string that does not match this format. *)
+(** Conversion from the printable representation of an Internet
+    address to its internal representation.  The argument string
+    consists of 4 numbers separated by periods ([XXX.YYY.ZZZ.TTT])
+    for IPv4 addresses, and up to 8 numbers separated by colons
+    for IPv6 addresses.  Raise [Failure] when given a string that
+    does not match these formats. *)
 
 val string_of_inet_addr : inet_addr -> string
-(** See {!Unix.inet_addr_of_string}. *)
+(** Return the printable representation of the given Internet address.
+    See {!Unix.inet_addr_of_string} for a description of the
+    printable representation. *)
 
 val inet_addr_any : inet_addr
-(** A special Internet address, for use only with [bind], representing
+(** A special IPv4 address, for use only with [bind], representing
    all the Internet addresses that the host machine possesses. *)
 
+val inet_addr_loopback : inet_addr
+(** A special IPv4 address representing the host machine ([127.0.0.1]). *)
+
+val inet6_addr_any : inet_addr
+(** A special IPv6 address, for use only with [bind], representing
+   all the Internet addresses that the host machine possesses. *)
+
+val inet6_addr_loopback : inet_addr
+(** A special IPv6 address representing the host machine ([::1]). *)
+
 
 (** {6 Sockets} *)
 
 
 type socket_domain =
     PF_UNIX                     (** Unix domain *)
-  | PF_INET                     (** Internet domain *)
-(** The type of socket domains. *)
+  | PF_INET                     (** Internet domain (IPv4) *)
+  | PF_INET6                    (** Internet domain (IPv6) *)
+(** The type of socket domains.  Not all platforms support
+    IPv6 sockets (type [PF_INET6]).  *)
 
 type socket_type =
     SOCK_STREAM                 (** Stream socket *)
@@ -874,6 +933,9 @@ val socket : socket_domain -> socket_type -> int -> file_descr
    given kind. The third argument is the protocol type; 0 selects
    the default protocol for that kind of sockets. *)
 
+val domain_of_sockaddr: sockaddr -> socket_domain
+(** Return the socket domain adequate for the given socket address. *)
+
 val socketpair :
   socket_domain -> socket_type -> int -> file_descr * file_descr
 (** Create a pair of unnamed sockets, connected together. *)
@@ -913,11 +975,11 @@ val getsockname : file_descr -> sockaddr
 val getpeername : file_descr -> sockaddr
 (** Return the address of the host connected to the given socket. *)
 
-type msg_flag = 
+type msg_flag =
     MSG_OOB
   | MSG_DONTROUTE
   | MSG_PEEK
-(** The flags for {!Unix.recv},  {!Unix.recvfrom}, 
+(** The flags for {!Unix.recv},  {!Unix.recvfrom},
    {!Unix.send} and {!Unix.sendto}. *)
 
 val recv : file_descr -> string -> int -> int -> msg_flag list -> int
@@ -947,6 +1009,8 @@ type socket_bool_option =
   | SO_DONTROUTE   (** Bypass the standard routing algorithms *)
   | SO_OOBINLINE   (** Leave out-of-band data in line *)
   | SO_ACCEPTCONN  (** Report whether socket listening is enabled *)
+  | TCP_NODELAY    (** Control the Nagle algorithm for TCP sockets *)
+  | IPV6_ONLY      (** Forbid binding an IPv6 socket to an IPv4 address *)
 (** The socket options that can be consulted with {!Unix.getsockopt}
    and modified with {!Unix.setsockopt}.  These options have a boolean
    ([true]/[false]) value. *)
@@ -954,7 +1018,7 @@ type socket_bool_option =
 type socket_int_option =
     SO_SNDBUF      (** Size of send buffer *)
   | SO_RCVBUF      (** Size of received buffer *)
-  | SO_ERROR       (** Report the error status and clear it *)
+  | SO_ERROR       (** Deprecated.  Use {!Unix.getsockopt_error} instead. *)
   | SO_TYPE        (** Report the socket type *)
   | SO_RCVLOWAT    (** Minimum number of bytes to process for input operations *)
   | SO_SNDLOWAT    (** Minimum number of bytes to process for output operations *)
@@ -969,7 +1033,7 @@ type socket_optint_option =
 (** The socket options that can be consulted with {!Unix.getsockopt_optint}
    and modified with {!Unix.setsockopt_optint}.  These options have a
    value of type [int option], with [None] meaning ``disabled''. *)
-                  
+
 type socket_float_option =
     SO_RCVTIMEO    (** Timeout for input operations *)
   | SO_SNDTIMEO    (** Timeout for output operations *)
@@ -985,39 +1049,37 @@ val getsockopt : file_descr -> socket_bool_option -> bool
 val setsockopt : file_descr -> socket_bool_option -> bool -> unit
 (** Set or clear a boolean-valued option in the given socket. *)
 
-external getsockopt_int :
-  file_descr -> socket_int_option -> int = "unix_getsockopt_int"
+val getsockopt_int : file_descr -> socket_int_option -> int
 (** Same as {!Unix.getsockopt} for an integer-valued socket option. *)
 
-external setsockopt_int :
-  file_descr -> socket_int_option -> int -> unit = "unix_setsockopt_int"
+val setsockopt_int : file_descr -> socket_int_option -> int -> unit
 (** Same as {!Unix.setsockopt} for an integer-valued socket option. *)
 
-external getsockopt_optint :
-  file_descr -> socket_optint_option -> int option = "unix_getsockopt_optint"
+val getsockopt_optint : file_descr -> socket_optint_option -> int option
 (** Same as {!Unix.getsockopt} for a socket option whose value is an [int option]. *)
 
-external setsockopt_optint :
-  file_descr -> socket_optint_option -> int option ->
-    unit = "unix_setsockopt_optint"
+val setsockopt_optint :
+      file_descr -> socket_optint_option -> int option -> unit
 (** Same as {!Unix.setsockopt} for a socket option whose value is an [int option]. *)
 
-external getsockopt_float :
-  file_descr -> socket_float_option -> float = "unix_getsockopt_float"
+val getsockopt_float : file_descr -> socket_float_option -> float
 (** Same as {!Unix.getsockopt} for a socket option whose value is a floating-point number. *)
 
-external setsockopt_float :
-  file_descr -> socket_float_option -> float -> unit = "unix_setsockopt_float"
+val setsockopt_float : file_descr -> socket_float_option -> float -> unit
 (** Same as {!Unix.setsockopt} for a socket option whose value is a floating-point number. *)
 
+val getsockopt_error : file_descr -> error option
+(** Return the error condition associated with the given socket,
+    and clear it. *)
+
 (** {6 High-level network connection functions} *)
 
 
 val open_connection : sockaddr -> in_channel * out_channel
 (** Connect to a server at the given address.
    Return a pair of buffered channels connected to the server.
-   Remember to call {!Pervasives.flush} on the output channel at the right times
-   to ensure correct synchronization. *)
+   Remember to call {!Pervasives.flush} on the output channel at the right
+   times to ensure correct synchronization. *)
 
 val shutdown_connection : in_channel -> unit
 (** ``Shut down'' a connection established with {!Unix.open_connection};
@@ -1039,14 +1101,14 @@ type host_entry =
   { h_name : string;
     h_aliases : string array;
     h_addrtype : socket_domain;
-    h_addr_list : inet_addr array 
+    h_addr_list : inet_addr array
   }
 (** Structure of entries in the [hosts] database. *)
 
 type protocol_entry =
-  { p_name : string; 
-    p_aliases : string array; 
-    p_proto : int 
+  { p_name : string;
+    p_aliases : string array;
+    p_proto : int
   }
 (** Structure of entries in the [protocols] database. *)
 
@@ -1054,7 +1116,7 @@ type service_entry =
   { s_name : string;
     s_aliases : string array;
     s_port : int;
-    s_proto : string 
+    s_proto : string
   }
 (** Structure of entries in the [services] database. *)
 
@@ -1085,6 +1147,65 @@ val getservbyport : int -> string -> service_entry
 (** Find an entry in [services] with the given service number,
    or raise [Not_found]. *)
 
+type addr_info =
+  { ai_family : socket_domain;          (** Socket domain *)
+    ai_socktype : socket_type;          (** Socket type *)
+    ai_protocol : int;                  (** Socket protocol number *)
+    ai_addr : sockaddr;                 (** Address *)
+    ai_canonname : string               (** Canonical host name  *)
+  }
+(** Address information returned by {!Unix.getaddrinfo}. *)
+
+type getaddrinfo_option =
+    AI_FAMILY of socket_domain          (** Impose the given socket domain *)
+  | AI_SOCKTYPE of socket_type          (** Impose the given socket type *)
+  | AI_PROTOCOL of int                  (** Impose the given protocol  *)
+  | AI_NUMERICHOST                      (** Do not call name resolver,
+                                            expect numeric IP address *)
+  | AI_CANONNAME                        (** Fill the [ai_canonname] field
+                                            of the result *)
+  | AI_PASSIVE                          (** Set address to ``any'' address
+                                            for use with {!Unix.bind} *)
+(** Options to {!Unix.getaddrinfo}. *)
+
+val getaddrinfo:
+  string -> string -> getaddrinfo_option list -> addr_info list
+(** [getaddrinfo host service opts] returns a list of {!Unix.addr_info}
+    records describing socket parameters and addresses suitable for
+    communicating with the given host and service.  The empty list is
+    returned if the host or service names are unknown, or the constraints
+    expressed in [opts] cannot be satisfied.
+
+    [host] is either a host name or the string representation of an IP
+    address.  [host] can be given as the empty string; in this case,
+    the ``any'' address or the ``loopback'' address are used,
+    depending whether [opts] contains [AI_PASSIVE].
+    [service] is either a service name or the string representation of
+    a port number.  [service] can be given as the empty string;
+    in this case, the port field of the returned addresses is set to 0.
+    [opts] is a possibly empty list of options that allows the caller
+    to force a particular socket domain (e.g. IPv6 only or IPv4 only)
+    or a particular socket type (e.g. TCP only or UDP only). *)
+
+type name_info =
+  { ni_hostname : string;               (** Name or IP address of host *)
+    ni_service : string }               (** Name of service or port number *)
+(** Host and service information returned by {!Unix.getnameinfo}. *)
+
+type getnameinfo_option =
+    NI_NOFQDN            (** Do not qualify local host names *)
+  | NI_NUMERICHOST       (** Always return host as IP address *)
+  | NI_NAMEREQD          (** Fail if host name cannot be determined *)
+  | NI_NUMERICSERV       (** Always return service as port number *)
+  | NI_DGRAM             (** Consider the service as UDP-based
+                             instead of the default TCP *)
+(** Options to {!Unix.getnameinfo}. *)
+
+val getnameinfo : sockaddr -> getnameinfo_option list -> name_info
+(** [getnameinfo addr opts] returns the host name and service name
+    corresponding to the socket address [addr].  [opts] is a possibly
+    empty list of options that governs how these names are obtained.
+    Raise [Not_found] if an error occurs. *)
 
 
 (** {6 Terminal interface} *)
@@ -1096,7 +1217,7 @@ val getservbyport : int -> string -> service_entry
    complete description. *)
 
 type terminal_io =
-  { 
+  {
     (* input modes *)
     mutable c_ignbrk : bool;  (** Ignore the break condition. *)
     mutable c_brkint : bool;  (** Signal interrupt on break condition. *)
@@ -1141,14 +1262,14 @@ type terminal_io =
                                  before the read request is satisfied. *)
     mutable c_vtime : int;    (** Maximum read wait (in 0.1s units). *)
     mutable c_vstart : char;  (** Start character (usually ctrl-Q). *)
-    mutable c_vstop : char;   (** Stop character (usually ctrl-S). *) 
+    mutable c_vstop : char;   (** Stop character (usually ctrl-S). *)
   }
 
 val tcgetattr : file_descr -> terminal_io
 (** Return the status of the terminal referred to by the given
    file descriptor. *)
 
-type setattr_when = 
+type setattr_when =
   TCSANOW
   | TCSADRAIN
   | TCSAFLUSH
@@ -1172,7 +1293,7 @@ val tcdrain : file_descr -> unit
 (** Waits until all output written on the given file descriptor
    has been transmitted. *)
 
-type flush_queue = 
+type flush_queue =
     TCIFLUSH
   | TCOFLUSH
   | TCIOFLUSH
@@ -1184,7 +1305,7 @@ val tcflush : file_descr -> flush_queue -> unit
    [TCOFLUSH] flushes data written but not transmitted, and
    [TCIOFLUSH] flushes both. *)
 
-type flow_action = 
+type flow_action =
     TCOOFF
   | TCOON
   | TCIOFF
